//
// $Id: RADIUShelpers.h,v 1.1 2004/01/27 16:20:30 holger Exp holger $
//
// RADIUS Plugin for pGina
// Copyright (c) 2004 Holger Weiss
//
// ---------------------------------------------------------------------------
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc., 59
// Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// ---------------------------------------------------------------------------
//
// The UNICODE conversion functions are slightly modified versions of similar
// functions taken from the PAM Plugin for pGina, copyright (c) 2003 Nathan
// Yocom.  The logging function, getWindowsVersion and the Registry functions
// are based on functions taken from pGina, copyright (c) 2002 Nathan Yocom.
// Some of the IP related code is taken from pam_radius_auth, copyright (c)
// 2003 Alan DeKok.  The pseudorandom integer algorithm is copyright (c) 1997
// Makoto Matsumoto and Takuji Nishimura (their code is LGPL'd, not GPL'd).
//

#ifndef RADIUShelpers_H
#define RADIUShelpers_H

#pragma once

#ifndef __AFXWIN_H__
#error include 'stdafx.h' before including this file for PCH
#endif				// __AFXWIN_H__

#include "radius.h"		// UINT4 is defined there

#ifndef BUFFER_SIZE
#define BUFFER_SIZE	1024
#endif				// BUFFER_SIZE

// Period parameters
#define N		624
#define M		397
#define MATRIX_A	0x9908b0df	// constant vector a
#define UPPER_MASK	0x80000000	// most significant w-r bits
#define LOWER_MASK	0x7fffffff	// least significant r bits

// Tempering parameters
#define TEMPERING_MASK_B	0x9d2c5680
#define TEMPERING_MASK_C	0xefc60000
#define TEMPERING_SHIFT_U(y)	(y >> 11)
#define TEMPERING_SHIFT_S(y)	(y << 7)
#define TEMPERING_SHIFT_T(y)	(y << 15)
#define TEMPERING_SHIFT_L(y)	(y >> 18)

// Windows versions
#define WINDOWS_SUCKY	0
#define WINDOWS_NT_4	1
#define WINDOWS_2000	2
#define WINDOWS_XP	3
#define WINDOWS_2003	4

static unsigned long mt[N];	// the array for the state vector
static int mti=N+1;		// mti==N+1 means mt[N] is not initialized

struct timezone
{
	int tz_minuteswest;
	int tz_dsttime;
};

// Exported functions
void            sgenrand(unsigned long seed);
unsigned long   genrand(void);
int             gettimeofday(struct timeval *time_Info, struct timezone *timezone_Info);
char           *convert_to_char(const TCHAR *from);
TCHAR          *convert_to_wchar(const char *from);
int             getWindowsVersion(void);
void            radiusLog(WORD log_type, char *string, ...);
char           *regReadString(LPCSTR location);
unsigned long   regReadUlong(LPCSTR location);
BOOL            regReadBool(LPCSTR location);
BOOL            regWriteString(LPCSTR value, LPCSTR location);
BOOL            regWriteUlong(unsigned long value, LPCSTR location);
BOOL            regWriteBool(BOOL value, LPCSTR location);
BOOL            regSecureKey(void);
char           *getHostID(void);
UINT4           ipstr2long(char *ip_str);
int             good_ipaddr(char *addr);
UINT4           get_ipaddr(char *host);
unsigned char  *xor(unsigned char *p, unsigned char *q, int length);
char           *stars(int n);
BOOL            isValidUser(LPCWSTR username);

#endif				// RADIUShelpers_H
